@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014 Canonical Ltd.
+ * Copyright © 2014-2017 Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License version 3,
@@ -31,34 +31,52 @@
 extern "C" {
 #endif
 
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 typedef enum
 {
     mir_event_type_key,
     mir_event_type_motion,
-    mir_event_type_surface,
+    MIR_DEPRECATED_ENUM(mir_event_type_surface, "mir_event_type_window"),
+    mir_event_type_window = mir_event_type_surface,
     mir_event_type_resize,
     mir_event_type_prompt_session_state_change,
     mir_event_type_orientation,
-    mir_event_type_close_surface,
+    MIR_DEPRECATED_ENUM(mir_event_type_close_surface, "mir_event_type_close_window"),
+    mir_event_type_close_window = mir_event_type_close_surface,
     /* Type for new style input event will be returned from mir_event_get_type
        when old style event type was mir_event_type_key or mir_event_type_motion */
     mir_event_type_input,
     mir_event_type_keymap,
-    mir_event_type_input_configuration,
-    mir_event_type_surface_output,
+    MIR_DEPRECATED_ENUM(mir_event_type_input_configuration, "mir_connection_set_input_config_change_callback and mir_event_type_input_device_state"),
+    MIR_DEPRECATED_ENUM(mir_event_type_surface_output, "mir_event_type_window_output"),
+    mir_event_type_window_output = mir_event_type_surface_output,
     mir_event_type_input_device_state,
+    MIR_DEPRECATED_ENUM(mir_event_type_surface_placement, "mir_event_type_window_placement"),
+    mir_event_type_window_placement = mir_event_type_surface_placement,
 } MirEventType;
+#pragma GCC diagnostic pop
 
-typedef struct MirSurfaceEvent MirSurfaceEvent;
+typedef struct MirSurfaceEvent MirSurfaceEvent
+    __attribute__ ((deprecated("use MirWindowEvent instead")));
+typedef struct MirSurfaceEvent MirWindowEvent;
 typedef struct MirResizeEvent MirResizeEvent;
 typedef struct MirPromptSessionEvent MirPromptSessionEvent;
 typedef struct MirOrientationEvent MirOrientationEvent;
-typedef struct MirCloseSurfaceEvent MirCloseSurfaceEvent;
+typedef struct MirCloseSurfaceEvent MirCloseSurfaceEvent
+    __attribute__ ((deprecated("use MirCloseWindowEvent instead")));
+typedef struct MirCloseSurfaceEvent MirCloseWindowEvent;
 typedef struct MirInputEvent MirInputEvent;
 typedef struct MirKeymapEvent MirKeymapEvent;
-typedef struct MirInputConfigurationEvent MirInputConfigurationEvent;
-typedef struct MirSurfaceOutputEvent MirSurfaceOutputEvent;
+typedef struct MirInputConfigurationEvent MirInputConfigurationEvent 
+    __attribute__ ((deprecated("Use MirInputDeviceStateEvent and the MirInputConfig callback instead")));
+typedef struct MirSurfaceOutputEvent MirSurfaceOutputEvent
+    __attribute__ ((deprecated("use MirWindowOutputEvent instead")));
+typedef struct MirSurfaceOutputEvent MirWindowOutputEvent;
 typedef struct MirInputDeviceStateEvent MirInputDeviceStateEvent;
+typedef struct MirSurfacePlacementEvent MirSurfacePlacementEvent
+    __attribute__ ((deprecated("use MirWindowPlacementEvent instead")));
+typedef struct MirSurfacePlacementEvent MirWindowPlacementEvent;
 
 typedef struct MirCookie MirCookie;
 
@@ -72,11 +90,13 @@ typedef struct MirEvent MirEvent;
 #include "mir_toolkit/events/input/input_event.h"
 #include "mir_toolkit/events/resize_event.h"
 #include "mir_toolkit/events/surface_event.h"
+#include "mir_toolkit/events/window_event.h"
 #include "mir_toolkit/events/orientation_event.h"
 #include "mir_toolkit/events/prompt_session_event.h"
 #include "mir_toolkit/events/keymap_event.h"
 #include "mir_toolkit/events/input_configuration_event.h"
 #include "mir_toolkit/events/surface_output_event.h"
+#include "mir_toolkit/events/window_output_event.h"
 #include "mir_toolkit/events/input_device_state_event.h"
 
 #ifdef __cplusplus
@@ -95,7 +115,7 @@ extern "C" {
  * \param [in] event The event
  * \return           The event type
  */
-MirEventType mir_event_get_type(MirEvent const* ev);
+MirEventType mir_event_get_type(MirEvent const* event);
 
 /**
  * Retrieve the MirInputEvent associated with a MirEvent of 
@@ -105,7 +125,7 @@ MirEventType mir_event_get_type(MirEvent const* ev);
  * \param [in] event The event
  * \return           The associated MirInputEvent
  */
-MirInputEvent const* mir_event_get_input_event(MirEvent const* ev);
+MirInputEvent const* mir_event_get_input_event(MirEvent const* event);
 
 /**
  * Retrieve the MirSurfaceEvent associated with a MirEvent of
@@ -115,7 +135,18 @@ MirInputEvent const* mir_event_get_input_event(MirEvent const* ev);
  * \param [in] event The event
  * \return           The associated MirSurfaceEvent
  */
-MirSurfaceEvent const* mir_event_get_surface_event(MirEvent const* ev);
+MirSurfaceEvent const* mir_event_get_surface_event(MirEvent const* event)
+__attribute__ ((deprecated("use mir_event_get_window_event instead")));
+
+/**
+ * Retrieve the MirWindowEvent associated with a MirEvent of
+ * type mir_event_type_window. See <mir_toolkit/events/surface_event.h>
+ * for accessors.
+ *
+ * \param [in] event The event
+ * \return           The associated MirWindowEvent
+ */
+MirWindowEvent const* mir_event_get_window_event(MirEvent const* event);
 
 /**
  * Retrieve the MirResizeEvent associated with a MirEvent of
@@ -125,7 +156,7 @@ MirSurfaceEvent const* mir_event_get_surface_event(MirEvent const* ev);
  * \param [in] event The event
  * \return           The associated MirResizeEvent
  */
-MirResizeEvent const* mir_event_get_resize_event(MirEvent const* ev);
+MirResizeEvent const* mir_event_get_resize_event(MirEvent const* event);
 
 /**
  * Retrieve the MirPromptSessionEvent associated with a MirEvent of
@@ -135,7 +166,7 @@ MirResizeEvent const* mir_event_get_resize_event(MirEvent const* ev);
  * \param [in] event The event
  * \return           The associated MirPromptSessionEvent
  */
-MirPromptSessionEvent const* mir_event_get_prompt_session_event(MirEvent const* ev);
+MirPromptSessionEvent const* mir_event_get_prompt_session_event(MirEvent const* event);
 
 /**
  * Retrieve the MirOrientationEvent associated with a MirEvent of
@@ -145,8 +176,11 @@ MirPromptSessionEvent const* mir_event_get_prompt_session_event(MirEvent const*
  * \param [in] event The event
  * \return           The associated MirOrientationEvent
  */
-MirOrientationEvent const* mir_event_get_orientation_event(MirEvent const* ev);
+MirOrientationEvent const* mir_event_get_orientation_event(MirEvent const* event);
 
+// Ignore use of deprecate MirCloseSurfaceEvent typedef in deprecated function (for now)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 /**
  * Retrieve the MirCloseSurfaceEvent associated with a MirEvent of
  * type mir_event_type_close_surface. The event is a request to close
@@ -160,8 +194,11 @@ MirOrientationEvent const* mir_event_get_orientation_event(MirEvent const* ev);
  * \param [in] event The event
  * \return           The associated MirCloseSurfaceEvent
  */
+/// @cond
 __attribute__ ((deprecated))
-MirCloseSurfaceEvent const* mir_event_get_close_surface_event(MirEvent const* ev);
+/// @endcond
+MirCloseSurfaceEvent const* mir_event_get_close_surface_event(MirEvent const* event);
+#pragma GCC diagnostic pop
 
 /**
  * Retrieve the MirKeymapEvent associated with a MirEvent of
@@ -171,17 +208,25 @@ MirCloseSurfaceEvent const* mir_event_get_close_surface_event(MirEvent const* ev
  * \param [in] event The event
  * \return           The associated MirKeymapEvent
  */
-MirKeymapEvent const* mir_event_get_keymap_event(MirEvent const* ev);
+MirKeymapEvent const* mir_event_get_keymap_event(MirEvent const* event);
 
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 /**
- * Retrieve the MirInputConfiguration associated with a MirEvent of
+ * Retrieve the MirInputConfig associated with a MirEvent of
  * type mir_event_type_input_configuration. The event signifies that the
  * input device configuration has changed.
  *
+ * \deprecated Input devices and changes to the input devices are indicated
+ * via the MirInputConfigCallback
  * \param [in] event The event
  * \return           The associated MirInputConfigurationEvent
  */
-MirInputConfigurationEvent const* mir_event_get_input_configuration_event(MirEvent const* ev);
+/// @cond
+__attribute__((deprecated))
+/// @endcond
+MirInputConfigurationEvent const* mir_event_get_input_configuration_event(MirEvent const* event);
+#pragma GCC diagnostic pop
 
 /**
  * Retrieve the MirSurfaceOutputEvent associated with a MirEvent of type
@@ -196,7 +241,23 @@ MirInputConfigurationEvent const* mir_event_get_input_configuration_event(MirEve
  * \param [in] event The event
  * \return           The associated MirSurfaceOutputEvent
  */
-MirSurfaceOutputEvent const* mir_event_get_surface_output_event(MirEvent const* ev);
+MirSurfaceOutputEvent const* mir_event_get_surface_output_event(MirEvent const* event)
+__attribute__((deprecated("use mir_event_get_window_output_event")));
+
+/**
+ * Retrieve the MirWindowOutputEvent associated with a MirEvent of type
+ * mir_event_type_window_output. The event signifies that the properties
+ * of the output the window is displayed upon have changed.
+ *
+ * A MirWindowOutputEvent is generated either when the properties of the
+ * output the window is primarily on change (for example: by user configuration
+ * of resolution) or when the output the window is primarily on changes
+ * (for example: when a user moves the window from one monitor to another).
+ *
+ * \param [in] event The event
+ * \return           The associated MirWindowOutputEvent
+ */
+MirWindowOutputEvent const* mir_event_get_window_output_event(MirEvent const* event);
 
 /**
  * Retrieve the MirInputDeviceStateEvent associated with a MirEvent of
@@ -207,41 +268,60 @@ MirSurfaceOutputEvent const* mir_event_get_surface_output_event(MirEvent const*
  * \param [in] event The event
  * \return           The associated MirInputConfigurationEvent
  */
-MirInputDeviceStateEvent const* mir_event_get_input_device_state_event(MirEvent const* ev);
+MirInputDeviceStateEvent const* mir_event_get_input_device_state_event(MirEvent const* event);
+
+/**
+ * Retrieve the MirSurfacePlacementEvent associated with a MirEvent of
+ * type mir_event_type_surface_placement. The event signifies that the
+ * the server has fulfilled a request for relative surface placement.
+ *
+ * \param [in] event The event
+ * \return           The associated MirSurfacePlacementEvent
+ */
+MirSurfacePlacementEvent const* mir_event_get_surface_placement_event(MirEvent const* event)
+__attribute__((deprecated("use mir_event_get_window_placement_event")));
+
+/**
+ * Retrieve the MirWindowPlacementEvent associated with a MirEvent of
+ * type mir_event_type_window_placement. The event signifies that the
+ * the server has fulfilled a request for relative window placement.
+ *
+ * \param [in] event The event
+ * \return           The associated MirWindowPlacementEvent
+ */
+MirWindowPlacementEvent const* mir_event_get_window_placement_event(MirEvent const* event);
 
 /*
- * 
- * !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+ * !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  * _________________________
  *< Don't use mir_event_ref >
- *-------------------------
+ * -------------------------
  *       \   ^__^
  *        \  (oo)\_______
-*            (__)\       )\/\
+ *           (__)\       )\/\
  *                ||----w |
  *                ||     || 
- * !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
- * NOTICE: mir_event_ref and mir_event_unref are implemented in terms of copy until 
- * such point whereas direct MirEvent access as deprecated. This means you must
- * use the return value as your new reference 
- *
+ * !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+ * NOTICE: mir_event_ref and mir_event_unref are implemented in terms of copy
+ * until such time that direct MirEvent access is deprecated. This means you
+ * must use the return value as your new reference.
  */
 
 /**
  * Reference this MirEvent and return a pointer to the
  * newly referenced instance
  *
- * \param[in] The event to reference
- * \return    The event pointer to now use
+ * \param[in] event The event to reference
+ * \return          The event pointer to now use
  */
-MirEvent const* mir_event_ref(MirEvent const* ev) __attribute__((warn_unused_result));
+MirEvent const* mir_event_ref(MirEvent const* event) __attribute__((warn_unused_result));
 
 /**
  * Release a reference to a MirEvent.
  *
- * \param[in] The event to un-reference
+ * \param[in] event The event to un-reference
  */
-void mir_event_unref(MirEvent const* ev);
+void mir_event_unref(MirEvent const* event);
 
 #ifdef __cplusplus
 }
