@@ -29,13 +29,17 @@
 extern "C" {
 #endif
 
+// Ignore use of deprecate MirSurfaceOutputEvent typedef in deprecated functions (for now)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 /**
  * Retrieve the DPI of the new output configuration of a MirSurfaceOutputEvent
  *
  * \param [in] ev   The event
  * \return          The new DPI value for the surface is primarily on.
  */
-int mir_surface_output_event_get_dpi(MirSurfaceOutputEvent const* ev);
+int mir_surface_output_event_get_dpi(MirSurfaceOutputEvent const* ev)
+__attribute__ ((deprecated("use mir_window_output_event_get_dpi instead")));
 
 /**
  * Retrieve the form factor of the new output configuration of a MirSurfaceOutputEvent
@@ -43,7 +47,8 @@ int mir_surface_output_event_get_dpi(MirSurfaceOutputEvent const* ev);
  * \param [in] ev   The event
  * \return          The new form factor of the output the surface is primarily on.
  */
-MirFormFactor mir_surface_output_event_get_form_factor(MirSurfaceOutputEvent const* ev);
+MirFormFactor mir_surface_output_event_get_form_factor(MirSurfaceOutputEvent const* ev)
+__attribute__ ((deprecated("use mir_window_output_event_get_form_factor instead")));
 
 /**
  * Retrieve the suggested scaling factor of the new output configuration of a
@@ -52,7 +57,20 @@ MirFormFactor mir_surface_output_event_get_form_factor(MirSurfaceOutputEvent con
  * \param [in] ev   The event
  * \return          The new scaling factor of the output the surface is primarily on.
  */
-float mir_surface_output_event_get_scale(MirSurfaceOutputEvent const* ev);
+float mir_surface_output_event_get_scale(MirSurfaceOutputEvent const* ev)
+__attribute__ ((deprecated("use mir_window_output_event_get_scale instead")));
+
+/**
+ * Retrieve the maximum refresh rate of the output(s) associated with a
+ * MirSurfaceOutputEvent. For variable refresh rate displays this represents
+ * the maximum refresh rate of the display to aim for, rather than a measurement
+ * of recent performance.
+ *
+ * \param [in] ev   The event
+ * \return          The refresh rate in Hz
+ */
+double mir_surface_output_event_get_refresh_rate(MirSurfaceOutputEvent const* ev)
+__attribute__ ((deprecated("use mir_window_output_event_get_refresh_rate instead")));
 
 /**
  * Retrieve the ID of the output this surface is on from a MirSurfaceOutputEvent
@@ -61,7 +79,10 @@ float mir_surface_output_event_get_scale(MirSurfaceOutputEvent const* ev);
  * \return          The ID of the output the surface is currently considered to be on.
  *                  (From MirDisplayOutput::output_id)
  */
-uint32_t mir_surface_output_event_get_output_id(MirSurfaceOutputEvent const *ev);
+uint32_t mir_surface_output_event_get_output_id(MirSurfaceOutputEvent const *ev)
+__attribute__ ((deprecated("use mir_window_output_event_get_output_id instead")));
+
+#pragma GCC diagnostic pop
 
 #ifdef __cplusplus
 }
