@@ -18,6 +18,7 @@
 
 #include "mir_test_framework/udev_environment.h"
 #include "mir/udev/wrapper.h"
+#include "mir/test/death.h"
 
 #include <gtest/gtest.h>
 #include <memory>
@@ -293,7 +294,7 @@ TEST_F(UdevWrapperDeathTest, DereferencingEndReturnsInvalidObject)
 
     devices.scan_devices();
 
-    EXPECT_EXIT((*devices.end()).subsystem(), KilledByInvalidMemoryAccess, "");
+    MIR_EXPECT_EXIT((*devices.end()).subsystem(), KilledByInvalidMemoryAccess, "");
 
     auto iter = devices.begin();
 
@@ -301,7 +302,7 @@ TEST_F(UdevWrapperDeathTest, DereferencingEndReturnsInvalidObject)
     {
         iter++;
     }
-    EXPECT_EXIT((*iter).subsystem(), KilledByInvalidMemoryAccess, "");
+    MIR_EXPECT_EXIT((*iter).subsystem(), KilledByInvalidMemoryAccess, "");
 }
 
 TEST_F(UdevWrapperTest, MemberDereferenceWorks)
@@ -328,7 +329,7 @@ TEST_F(UdevWrapperDeathTest, MemberDereferenceOfEndDies)
 
     devices.scan_devices();
 
-    EXPECT_EXIT(devices.end()->subsystem(), KilledByInvalidMemoryAccess, "");
+    MIR_EXPECT_EXIT(devices.end()->subsystem(), KilledByInvalidMemoryAccess, "");
 
     auto iter = devices.begin();
 
@@ -336,7 +337,7 @@ TEST_F(UdevWrapperDeathTest, MemberDereferenceOfEndDies)
     {
         iter++;
     }
-    EXPECT_EXIT(iter->subsystem(), KilledByInvalidMemoryAccess, "");
+    MIR_EXPECT_EXIT(iter->subsystem(), KilledByInvalidMemoryAccess, "");
 }
 
 TEST_F(UdevWrapperTest, UdevMonitorDoesNotTriggerBeforeEnabling)
